@@ -18,7 +18,7 @@
 
 #include <grpcpp/support/client_interceptor.h>
 
-#include "src/core/lib/gprpp/crash.h"
+#include "src/core/util/crash.h"
 
 namespace grpc {
 
